.. Copyright (c) Moshe Zadka
   See LICENSE for details.

Gather
------

Gather -- gather all plugins into a dictionary

.. image:: https://travis-ci.org/moshez/gather.svg?branch=master
    :target: https://travis-ci.org/moshez/gather

.. image:: https://readthedocs.org/projects/gather/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: https://readthedocs.org/projects/gather/

Contributing
============

We welcome all issues, and PRs.
We are committed to a positive environment:
see our code of conduct at the root of the tree.

Running:

.. code::

  $ tox

Should DTRT -- if it passes, it means
unit tests are passing, and 100% coverage.
Pull requests can be submitted without passing :code:`tox`,
but will have to be fixed before merging.
We are happy to give guidance as to fixing.

Contributors
=============

* Moshe Zadka <zadka.moshe@gmail.com>
* Mark R. Williams <mrw@enotuniq.org>

License
=======

MIT License
